/*
  Bear Engine

  Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file linear_equality.cpp
 * \brief Implementation of the bear::engine::linear_equality class.
 * \author Julien Jorge.
 */
#include "engine/expr/linear_equality.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Contructor.
 * \param left The left operand.
 * \param right The right operand.
 */
bear::engine::linear_equality::linear_equality
( const linear_expression& left, const linear_expression& right )
  : m_left(left), m_right(right)
{

} // linear_equality::linear_equality()

/*----------------------------------------------------------------------------*/
/**
 * \brief Create a copy of this expression.
 */
bear::engine::base_boolean_expression*
bear::engine::linear_equality::clone() const
{
  return new linear_equality(*this);
} // linear_equality::linear_equality()

/*----------------------------------------------------------------------------*/
/**
 * \brief Evaluate the expression.
 */
bool bear::engine::linear_equality::evaluate() const
{
  return m_left.evaluate() == m_right.evaluate();
} // linear_equality::evaluate()
