/*
  Bear Engine

  Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file code/derived_item_handle.cpp
 * \brief Implementation of the universe::derived_item_handle class.
 * \author Julien Jorge
 */

/*----------------------------------------------------------------------------*/
/**
 * \brief Default Constructor.
 */
template<typename DerivedType, typename ItemType>
bear::universe::derived_item_handle<DerivedType, ItemType>::
derived_item_handle()
  : m_derived(NULL)
{

} // derived_item_handle::derived_item_handle()

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 * \param item The item on which we keep a handle.
 */
template<typename DerivedType, typename ItemType>
bear::universe::derived_item_handle<DerivedType, ItemType>::
derived_item_handle( ItemType* item )
  : m_item(item)
{
  cast_item();
} // derived_item_handle::derived_item_handle()

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 * \param item The item on which we keep a handle.
 */
template<typename DerivedType, typename ItemType>
bear::universe::derived_item_handle<DerivedType, ItemType>::
derived_item_handle( ItemType& item )
  : m_item(item)
{
  cast_item();
} // derived_item_handle::derived_item_handle()

/*----------------------------------------------------------------------------*/
/**
 * \brief Copy constructor.
 */
template<typename DerivedType, typename ItemType>
bear::universe::derived_item_handle<DerivedType, ItemType>::
derived_item_handle( const self_type& that )
  : m_item(that.m_item), m_derived(that.m_derived)
{

} // derived_item_handle::derived_item_handle()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the pointer on the derived class.
 */
template<typename DerivedType, typename ItemType>
DerivedType*
bear::universe::derived_item_handle<DerivedType, ItemType>::get() const
{
  return m_derived;
} // derived_item_handle::get()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the pointer on the handled item.
 */
template<typename DerivedType, typename ItemType>
ItemType*
bear::universe::derived_item_handle<DerivedType, ItemType>::get_item() const
{
  return m_item.get();
} // derived_item_handle::get_item()

/*----------------------------------------------------------------------------*/
/**
 * \brief Dereference operator.
 */
template<typename DerivedType, typename ItemType>
DerivedType&
bear::universe::derived_item_handle<DerivedType, ItemType>::operator*() const
{
  return *m_derived;
} // derived_item_handle::operator*()

/*----------------------------------------------------------------------------*/
/**
 * \brief Pointer-to-member operator.
 */
template<typename DerivedType, typename ItemType>
DerivedType*
bear::universe::derived_item_handle<DerivedType, ItemType>::operator->() const
{
  return m_derived;
} // derived_item_handle::operator->()

/*----------------------------------------------------------------------------*/
/**
 * \brief Assign a new item to keep an handle to.
 * \param item The item.
 */
template<typename DerivedType, typename ItemType>
typename bear::universe::derived_item_handle<DerivedType, ItemType>::self_type&
bear::universe::derived_item_handle<DerivedType, ItemType>::operator=
( ItemType* item )
{
  m_item = item;
  cast_item();
  return *this;
} // derived_item_handle::operator=()

/*----------------------------------------------------------------------------*/
/**
 * \brief Assignment operator.
 */
template<typename DerivedType, typename ItemType>
typename bear::universe::derived_item_handle<DerivedType, ItemType>::self_type&
bear::universe::derived_item_handle<DerivedType, ItemType>::operator=
( const self_type& that )
{
  m_item = that.m_item;
  m_derived = that.m_derived;
  return *this;
} // derived_item_handle::operator=()

/*----------------------------------------------------------------------------*/
/**
 * \brief Equality.
 * \param item The item to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator==
( const ItemType* item ) const
{
  return m_item == item;
} // derived_item_handle::operator==()

/*----------------------------------------------------------------------------*/
/**
 * \brief Equality.
 * \param item The item to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator==
( const DerivedType* item ) const
{
  return m_derived == item;
} // derived_item_handle::operator==()

/*----------------------------------------------------------------------------*/
/**
 * \brief Equality.
 * \param that The instance to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator==
( const self_type& that ) const
{
  return m_item == that.m_item;
} // derived_item_handle::operator==()

/*----------------------------------------------------------------------------*/
/**
 * \brief Disequality.
 * \param item The pointer to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator!=
( const ItemType* item ) const
{
  return !(*this == item);
} // derived_item_handle::operator!=()

/*----------------------------------------------------------------------------*/
/**
 * \brief Disequality.
 * \param item The pointer to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator!=
( const DerivedType* item ) const
{
  return !(*this == item);
} // derived_item_handle::operator!=()

/*----------------------------------------------------------------------------*/
/**
 * \brief Disequality.
 * \param that The instance to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator!=
( const self_type& that ) const
{
  return !(*this == that);
} // derived_item_handle::operator!=()

/*----------------------------------------------------------------------------*/
/**
 * \brief "Less than" operator.
 * \param that The pointer to compare to.
 */
template<typename DerivedType, typename ItemType>
bool bear::universe::derived_item_handle<DerivedType, ItemType>::operator<
( const self_type& that ) const
{
  return m_item < that.m_item;
} // derived_item_handle::operator<()

/*----------------------------------------------------------------------------*/
/**
 * \brief Dynamically cast the item into the derived type.
 */
template<typename DerivedType, typename ItemType>
void bear::universe::derived_item_handle<DerivedType, ItemType>::cast_item()
{
  m_derived = dynamic_cast<DerivedType*>(m_item.get());
} // derived_item_handle::cast_item()
