/*
    Bear Engine - Model editor

    Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/snapshot_frame.hpp
 * \brief The window displaying the current snapshot of an action.
 * \author Sbastien Angibaud
 */
#ifndef __BF_SNAPSHOT_FRAME_HPP__
#define __BF_SNAPSHOT_FRAME_HPP__

#include "bf/model_frame.hpp"
#include "bf/base_file_edit.hpp"
#include <wx/combobox.h>
#include "bf/spin_ctrl.hpp"
#include <wx/spinctrl.h>
#include <wx/wx.h>
#include <string>

namespace bf
{
  class ingame_view;
  class snapshot;

  /**
   * \brief The window displaying the list of marks of an action.
   * \author Sbastien Angibaud
   */
  class snapshot_frame:
    public wxPanel
  {
    /** \brief The identifiers of the controls. */
    enum control_id
      {
        IDC_DATE_CTRL,
        IDC_MARK_CHOICE,
        IDC_MARK_PLACEMENT,
        IDC_VISIBILITY,
        IDC_FUNCTION,
        IDC_GLOBALLY_SOUND,
        IDC_SOUND_FILE,
	IDC_ALIGNMENT,
	IDC_SIZE
      }; // enum control_id
  
  public:
    snapshot_frame( wxWindow* parent);

    void set_model_frame( model_frame* f );
    void update_action();
    void update_snapshot();
    void update_mark();

  private:
    void create_controls();
    void create_member_controls();
    void create_sizer_controls();
    wxSizer* create_marks_sizer();
    wxSizer* create_sound_sizer();
    
    void clear();
    void fill();
    void fill_mark();
    
    void placement_change();
    void alignment_change();
    void size_change();
    void sound_change();
    
    void on_close(wxCloseEvent& event);
    void on_date_change( wxCommandEvent& event );
    void on_mark_change( wxCommandEvent& event );
    void on_alignment_choice_change( wxCommandEvent& event );
    void on_placement_change( spin_event<double>& event );
    void on_alignment_change( spin_event<double>& event );
    void on_size_change( spin_event<double>& event );
    void on_depth_change( wxSpinEvent& event );
    void on_visibility_change( wxCommandEvent& event );
    void on_function_change( wxCommandEvent& event );
    void on_globally_sound_change( wxCommandEvent& event );
    void on_sound_file_edit( wxCommandEvent& event );
    void on_sound_file_change( wxCommandEvent& event );
    
  private:
    /** \brief The current model_frame. */
    model_frame* m_model_frame;

    /** \brief The list of marks, presented to the user. */
    snapshot* m_snapshot;

    /** \brief The button control in which we configure the date of
        the snapshot. */
    wxButton* m_date_button;

    /** \brief The text control in which we configure the function to call. */
    wxButton* m_function_button;

    /** \brief The spin control in which we configure the left of the mark.*/
    spin_ctrl<double>* m_mark_left_spin;

    /** \brief The spin control in which we configure the bottom of the mark.*/
    spin_ctrl<double>* m_mark_bottom_spin;

    /** \brief The spin control in which we configure the z-coordinate of 
        the box. */
    wxSpinCtrl* m_mark_depth_spin;

    /** \brief The spin control in which we configure the angle of the mark.*/
    spin_ctrl<double>* m_mark_angle_spin;

    /** \brief The spin control in which we configure the current mark. */
    wxChoice* m_mark_choice;

    /** \brief The button control to check the visibily of the mark. */
    wxCheckBox* m_mark_visible_box;

    /** \brief The sound button to edit path. */
    wxButton* m_sound_button;

     /** \brief Text control in which we display the path to the sound. */
    wxTextCtrl* m_sound_path;

    /** \brief The button control to check if the sound is global. */
    wxCheckBox* m_globally_sound_box;

    /** \brief The spin control in which we configure the
        width of the action.*/
    spin_ctrl<double>* m_width_spin;
    
    /** \brief The spin control in which we configure 
        the height of the action.*/
    spin_ctrl<double>* m_height_spin;

    /** \brief The spin control in which we configure 
        the value of alignment on x-coordinate.*/
    spin_ctrl<double>* m_x_alignment_value_spin;
    
    /** \brief The spin control in which we configure 
        the value of alignment on y-coordinate.*/
    spin_ctrl<double>* m_y_alignment_value_spin;

    /** \brief The spin control in which we choose 
        the type of alignment on x-coordinate.*/
    wxChoice* m_x_alignment_choice;
    
    /** \brief The spin control in which we choose 
        the type of alignment on y-coordinate.*/
    wxChoice* m_y_alignment_choice;
    
    DECLARE_EVENT_TABLE()

  }; // class snapshot_frame
} // namespace bf

#endif // __BF_SNAPSHOT_FRAME_HPP__
